<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Kids Love Pro
 * @since Kids Love Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'kids_love_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','kids-love-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'kids-love-pro' ),
	'panel'             => 'kids_love_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'kids_love_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kids_Love_Pro_Switch_Control( $wp_customize, 'kids_love_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_counter_section',
	'on_off_label' 		=> kids_love_pro_switch_options(),
) ) );

// counter image setting and control.
$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'kids_love_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_love_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'kids-love-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'kids-love-pro' ), 1920, 500 ),
		'section'     		=> 'kids_love_pro_counter_section',
		'active_callback'	=> 'kids_love_pro_is_counter_section_enable',
) ) );

for ( $i = 1; $i <= 4; $i++ ) :

	// counter icon setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Kids_Love_Pro_Icon_Picker( $wp_customize, 'kids_love_pro_theme_options[counter_icon_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Icon %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_counter_section',
		'active_callback' 	=> 'kids_love_pro_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kids_love_pro_theme_options[counter_value_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_counter_section',
		'active_callback' 	=> 'kids_love_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kids_love_pro_theme_options[counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_counter_section',
		'active_callback' 	=> 'kids_love_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Kids_Love_Pro_Customize_Horizontal_Line( $wp_customize, 'kids_love_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'kids_love_pro_counter_section',
			'active_callback' => 'kids_love_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

