<?php
/**
 * Introduction Section options
 *
 * @package Theme Palace
 * @subpackage Kids Love Pro
 * @since Kids Love Pro 1.0.0
 */

// Add Introduction section
$wp_customize->add_section( 'kids_love_pro_introduction_section', array(
	'title'             => esc_html__( 'Introduction/Slider','kids-love-pro' ),
	'description'       => esc_html__( 'Introduction Section options.', 'kids-love-pro' ),
	'panel'             => 'kids_love_pro_front_page_panel',
) );

// Introduction content enable control and setting
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_section_enable]', array(
	'default'			=> 	$options['introduction_section_enable'],
	'sanitize_callback' => 'kids_love_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kids_Love_Pro_Switch_Control( $wp_customize, 'kids_love_pro_theme_options[introduction_section_enable]', array(
	'label'             => esc_html__( 'Introduction Section Enable', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_introduction_section',
	'on_off_label' 		=> kids_love_pro_switch_options(),
) ) );

// introduction btn title setting and control
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_btn_title]', array(
	'label'           	=>	esc_html__( 'Button Label', 'kids-love-pro' ),
	'section'        	=> 'kids_love_pro_introduction_section',
	'active_callback' 	=> 'kids_love_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'kids_love_pro_theme_options[slider_overlay_option]', array(
		'default'           => $options['slider_overlay_option'],
		'sanitize_callback' => 'kids_love_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

$wp_customize->add_control( 'kids_love_pro_theme_options[slider_overlay_option]', array(
	'type'				=> 'radio',
	'label'             => esc_html__( 'Slider Overlay Option', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_introduction_section',
	'choices'				=> array( 
		'image-overlay'     => esc_html__( 'Overlay on Image', 'kids-love-pro' ),
		'content-overlay'     => esc_html__( 'Overlay on Text', 'kids-love-pro' ),
		)
) );

// Introduction content type control and setting
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_content_type]', array(
	'default'          	=> $options['introduction_content_type'],
	'sanitize_callback' => 'kids_love_pro_sanitize_select',
) );

$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_introduction_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kids_love_pro_is_introduction_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kids-love-pro' ),
		'post' 		=> esc_html__( 'Post', 'kids-love-pro' ),
		'category' 		=> esc_html__( 'Category', 'kids-love-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'kids-love-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_count]', array(
	'default'          	=> $options['introduction_count'],
	'sanitize_callback' => 'kids_love_pro_sanitize_number_range',
	'validate_callback' => 'kids_love_pro_validate_introduction_count',
) );

$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'kids-love-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_introduction_section',
	'active_callback'   => 'kids_love_pro_is_introduction_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );
for ( $i = 1; $i <= $options['introduction_count']; $i++ ) :

	if( $options['home_layout'] !== 'fourth-design' ):

	// introduction sub title setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'refresh',
	) );

	$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_sub_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sub Title %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_introduction_section',
		'active_callback' 	=> 'kids_love_pro_is_introduction_section_enable',
		'type'				=> 'text',
	) );

	endif;

	// introduction pages drop down chooser control and setting
	$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kids_love_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kids_Love_Pro_Dropdown_Chooser( $wp_customize, 'kids_love_pro_theme_options[introduction_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'kids-love-pro' ), $i ),
		'section'           => 'kids_love_pro_introduction_section',
		'choices'			=> kids_love_pro_page_choices(),
		'active_callback'	=> 'kids_love_pro_is_introduction_section_content_page_enable',
	) ) );

	// introduction posts drop down chooser control and setting
	$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kids_love_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kids_Love_Pro_Dropdown_Chooser( $wp_customize, 'kids_love_pro_theme_options[introduction_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kids-love-pro' ), $i ),
		'section'           => 'kids_love_pro_introduction_section',
		'choices'			=> kids_love_pro_post_choices(),
		'active_callback'	=> 'kids_love_pro_is_introduction_section_content_post_enable',
	) ) );

	// introduction sub title setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_introduction_section',
		'active_callback' 	=> 'kids_love_pro_is_introduction_section_content_custom_enable',
		'type'				=> 'text',
	) );


	// intro description setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[intro_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'kids_love_pro_theme_options[intro_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'kids-love-pro' ), $i ),
		'section'        	=> 'kids_love_pro_introduction_section',
		'active_callback' 	=> 'kids_love_pro_is_introduction_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// introduction image setting and control.
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_image_' . $i . ']', array(
	'sanitize_callback' => 'kids_love_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_love_pro_theme_options[introduction_image_' . $i . ']',
		array(
		'label'       		=> sprintf( esc_html__( 'image %d', 'kids-love-pro' ), $i ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'kids-love-pro' ), 600, 680 ),
		'section'     		=> 'kids_love_pro_introduction_section',
		'active_callback'	=> 'kids_love_pro_is_introduction_section_content_custom_enable',
) ) );


// introduction btn link setting and control
$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_btn_link_' . $i . ']', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'kids_love_pro_theme_options[introduction_btn_link_' . $i . ']', array(
	'label'           	=> sprintf( esc_html__( 'Button Url %d', 'kids-love-pro' ), $i ),
	'section'        	=> 'kids_love_pro_introduction_section',
	'active_callback' 	=> 'kids_love_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'url',
) );

// introduction hr setting and control
	$wp_customize->add_setting( 'kids_love_pro_theme_options[introduction_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Kids_Love_Pro_Customize_Horizontal_Line( $wp_customize, 'kids_love_pro_theme_options[introduction_hr_'. $i .']',
		array(
			'section'         => 'kids_love_pro_introduction_section',
			'active_callback' => 'kids_love_pro_is_introduction_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kids_love_pro_theme_options[introduction_content_category]', array(
	'sanitize_callback' => 'kids_love_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kids_Love_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kids_love_pro_theme_options[introduction_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kids-love-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kids-love-pro' ),
	'section'           => 'kids_love_pro_introduction_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kids_love_pro_is_introduction_section_content_category_enable'
) ) );
