<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Kids Love Pro
 * @since Kids Love Pro 1.0.0
 */
if ( ! function_exists( 'kids_love_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Kids Love Pro 1.0.0
    */
    function kids_love_pro_add_featured_section() {
    	$options = kids_love_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'kids_love_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }

        // Render featured section now.
        kids_love_pro_render_featured_section();
    }
endif;

if ( ! function_exists( 'kids_love_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Kids Love Pro 1.0.0
   *
   */
   function kids_love_pro_render_featured_section() {
        $options = kids_love_pro_get_theme_options();
        $featured_categories  = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : array();
        $i = 1;
        $c = 1;

        if ( empty( $featured_categories ) ) {
            return;
        } ?>
        <div id="kids_love_pro_featured_section" class="relative page-section">
            <div id="our-gallery">
                <div class="wrapper">
                    <div class="tab-section">
                        <ul class="tabs">
                            <?php foreach ( $featured_categories as $category ) : ?>
                                <li class="tab-link <?php echo ( 1 == $i ) ? 'active' : ''; ?>" data-tab="<?php echo absint( $category ); ?>"><a href="#."><?php echo esc_html( get_cat_name( $category ) ) ?></a></li>
                            <?php $i++; endforeach; ?>
                        </ul>
                    </div><!-- .tab-section -->

                    <div class="tab-section-content">
                        <?php if ( ! empty( $options['featured_title'] ) || ! empty( $options['featured_sub_title'] ) ) : ?>
                            <div class="section-header">
                                <?php if ( ! empty( $options['featured_sub_title'] ) ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['featured_sub_title'] ); ?></p>
                                <?php endif; 

                                if ( ! empty( $options['featured_title'] ) ) : ?>
                                    <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ); ?></h2>
                                <?php endif; ?>
                            </div><!-- .section-header -->
                        <?php endif; ?>

                        <?php foreach ( $featured_categories as $category ) : 
                            $args = array(
                                'post_type'         => 'post',
                                'posts_per_page'    => 3,
                                'cat'               => absint( $category ),
                                'ignore_sticky_posts'   => true,
                            ); 
                            $query = new WP_Query( $args ); ?>
                            <div id="<?php echo absint( $category ); ?>" class="tab-content grid <?php echo ( 1 == $c ) ? 'active' : ''; ?>">
                                <?php while ( $query->have_posts() ) : $query->the_post(); ?>
                                    <article class="grid-item">
                                        <div class="featured-image" style="background-image: url('<?php echo has_post_thumbnail() ? esc_url( get_the_post_thumbnail_url( get_the_id() ) ) : esc_url( get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg' ); ?>');">
                                            <div class="gallery-overlay"><div class="bg"></div></div>
                                            <header class="entry-header">
                                                <?php if ( has_post_thumbnail() ) : ?>
                                                    <a href="<?php the_post_thumbnail_url( 'full' ); ?>" class="icon popup"><i class="fa fa-arrows-alt"></i></a>
                                                <?php endif; ?>
                                                <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                            </header>
                                        </div><!-- .featured-image -->
                                    </article>
                                <?php $c++; endwhile; 
                                wp_reset_postdata(); ?>

                            </div><!-- .tab-content -->
                        <?php endforeach; ?>

                    </div><!-- .tab-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #our-gallery -->

        </div>
        
    <?php }
endif;